pub fn parse_condition(
string: &str,
) -> Result<(&str, bool, Option<(MatchOp, &str)>)>Expand description
Parse the bits of a condition atom
This method parses a condition atom. It returns the “metadata identifier” (e.g. the name of the piece of metadata), a flag indicating whether the condition is negated or not and, optionally, the matching operator and a string representation of the right-hand side value.
The matching operator and value may be None. In this case, the condition
parsed is expected to check for the existence of a piece of metadata.