pub enum MatchOp {
Equivalence,
LowerThan,
GreaterThan,
LowerThanOrEqual,
GreaterThanOrEqual,
Contains,
}Expand description
Match operators
These operators define how the piece of metadata queried from the issue is compared to the literal provided with the conditon atom. The former is considered the “left-hand value” while the latter is considered the “right-hand value” in this context.
Variants
Equivalence
Match if the values are evivalent
LowerThan
Match if the left-hand value is lower than the right-hand value.
GreaterThan
Match if the left-hand value is greater than the right-hand value.
LowerThanOrEqual
Match if the left-hand value is lower than the right-hand value or equal.
GreaterThanOrEqual
Match if the left-hand value is greater than the right-hand value or equal.
Contains
Match if the left-hand value contains or is equal to the right-hand value.