pub enum StateRelation {
Extends,
Overrides,
}Expand description
Enumeration type for classificatoin of relations
Instances of this enum describe the relation between two states.
Variants
Extends
The issue extends another state
All conditions are inherited. If both the extending and the extended state are enabled for an issue, the extending state is chosen.
Overrides
The issue overrides another state
If both the overriding and the overridden state are enabled for an issue, the overriding state is chosen. However, no conditions are inherited from the overridden state.